@@ -5,7 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build flex
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 sub bin_dir
@@ -20,6 +20,14 @@ sub bin_dir
   return $class->SUPER::bin_dir;
 }
 
+
+sub alien_helper
+{
+  return {
+    flex => sub { 'flex' },
+  };
+}
+
 1;
 
 __END__
@@ -34,7 +42,7 @@ Alien::flex - Find or build flex
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -58,6 +66,14 @@ From Alien::Base Build.PL
 
 This package can be used by other CPAN modules that require flex.
 
+=head1 HELPERS
+
+=head2 flex
+
+ %{flex}
+
+Returns the name of the flex command.  Usually just C<flex>.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
